==> thunar-volman_4.16.0.orig.tar.bz2: thunar-volman-4.16.0/README.md <==
[![License](https://img.shields.io/badge/License-GPL%20v2-blue.svg)](https://gitlab.xfce.org/xfce/thunar-volman/-/blob/master/COPYING)

# thunar-volman


Thunar-volman is an extension for the Thunar File Manager, which enables
automatic management of removable drives and media. For example, if
thunar-volman is installed and configured properly, and you plug in your
digital camera, it will automatically spawn your preferred photo application
and import the new pictures from your camera.

It was designed to look and behave similar to gnome-volume-manager to get
consistent removable drive and media management in Xfce and GNOME. This is
to help GNOME refugees and people using both Xfce and GNOME (i.e. having to
use GNOME at the office).

----

### Homepage

[Thunar-volman documentation](https://docs.xfce.org/xfce/thunar-volman/start)

### Changelog

See [NEWS](https://gitlab.xfce.org/xfce/thunar-volman/-/blob/master/NEWS) for details on changes and fixes made in the current release.

### Source Code Repository

[Thunar-volman source code](https://gitlab.xfce.org/xfce/thunar-volman)

### Download a Release Tarball

[Thunar-volman archive](https://archive.xfce.org/src/xfce/thunar-volman)
    or
[Thunar-volman tags](https://gitlab.xfce.org/xfce/thunar-volman/-/tags)

### Installation

From source: 

    % cd thunar-volman
    % ./autogen.sh
    % make
    % make install

From release tarball:

    % tar xf thunar-volman-<version>.tar.bz2
    % cd thunar-volman-<version>
    % ./configure
    % make
    % make install

### Reporting Bugs

Visit the [reporting bugs](https://docs.xfce.org/xfce/thunar-volman/bugs) page to view currently open bug reports and instructions on reporting new bugs or submitting bugfixes.

==> thunar-volman_4.20.0.orig.tar.bz2: thunar-volman-4.20.0/README.md <==
[![License](https://img.shields.io/badge/License-GPL%20v2-blue.svg)](https://gitlab.xfce.org/xfce/thunar-volman/-/blob/master/COPYING)

# thunar-volman


Thunar-volman is an extension for the Thunar File Manager, which enables
automatic management of removable drives and media. For example, if
thunar-volman is installed and configured properly, and you plug in your
digital camera, it will automatically spawn your preferred photo application
and import the new pictures from your camera.

It was designed to look and behave similar to gnome-volume-manager to get
consistent removable drive and media management in Xfce and GNOME. This is
to help GNOME refugees and people using both Xfce and GNOME (i.e. having to
use GNOME at the office).

----

### Homepage

[Thunar-volman documentation](https://docs.xfce.org/xfce/thunar/thunar-volman)

### Changelog

See [NEWS](https://gitlab.xfce.org/xfce/thunar-volman/-/blob/master/NEWS) for details on changes and fixes made in the current release.

### Source Code Repository

[Thunar-volman source code](https://gitlab.xfce.org/xfce/thunar-volman)

### Download a Release Tarball

[Thunar-volman archive](https://archive.xfce.org/src/xfce/thunar-volman)
    or
[Thunar-volman tags](https://gitlab.xfce.org/xfce/thunar-volman/-/tags)

### Installation

From source: 

    % cd thunar-volman
    % ./autogen.sh
    % make
    % make install

From release tarball:

    % tar xf thunar-volman-<version>.tar.bz2
    % cd thunar-volman-<version>
    % ./configure
    % make
    % make install

### Reporting Bugs

Visit the [reporting bugs](https://docs.xfce.org/xfce/thunar-volman/bugs) page to view currently open bug reports and instructions on reporting new bugs or submitting bugfixes.
